<?php
require_once dirname(__DIR__).'/models/Article.php';
require_once dirname(__DIR__).'/services/ArticleForm.php';
require_once dirname(__DIR__).'/services/ArticleManager.php';
require_once dirname(__DIR__).'/services/View.php';


class ArticleController
{
    private $articleManager;

    public function __construct(ArticleManager $articleManager)
    {
        $this->articleManager = $articleManager;
    }

    public function index()
    {
        $articles = $this->articleManager->findAll();

        View::view('index.php', ['articles' => $articles]);
    }

    public function show()
    {
        $article_id = null;

        if (!empty($_GET['id']) && ctype_digit($_GET['id'])) {
            $article_id = $_GET['id'];
        }

        $article = $this->articleManager->find($article_id);

        View::view('index.php', ['article' => $article]);
    }


    public function create()
    {
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $form = new ArticleForm($_POST);

            if ($form->create($this->articleManager)) {
                $newArticle = $this->articleManager->findLast();
            }

        } else {
            $form = new ArticleForm();
        }

        View::view('article_form.php', ['form' => $form]);
    }

    public function update()
    {
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;
        $article = $this->articleManager->find($id);
        $form = new articleForm([
            'id' => $id,
            'title' => $article->getTitle(),
            'content' => $article->getContent(),
            'created_at' => $article->getCreated_at(),
        ]);

        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $form = new ArticleForm($_POST);
            if ($form->update($id, $this->articleManager)) {
                return redirect('/');
            }
        }
    }

    public function delete()
    {
        if ($_SERVER['REQUEST_METHOD'] === 'DELETE') {
            $id = isset($_GET['id']) ? intval($_GET['id']) : 0;
            $this->articleManager->delete($id);
        }
    }
}