<?php
require_once dirname(__DIR__).'/models/Database.php';
require_once dirname(__DIR__).'/models/Article.php';

class ArticleManager
{
    private $pdo;

    public function __construct(PDO $pdo)
    {
        $this->pdo = $pdo;
    }

    public function findAll(): array
    {
        $query = $this->pdo->prepare('SELECT * FROM article ORDER BY id DESC');
        $query->execute();

        $articles = [];
        while ($articleData = $query->fetch(PDO::FETCH_ASSOC)) {
            $article = new Article(
                $articleData['title'],
                $articleData['content'],
                $articleData['created_at'],
                $articleData['id']
            );

            $articles[] = $article;
        }

        return $articles;
    }

    public function find($id): Article
    {
        $query = $this->pdo->prepare('SELECT * FROM article WHERE id = :id');
        $query->bindValue(':id', $id);
        $query->execute();

        $articleData = $query->fetch(PDO::FETCH_ASSOC);
        if ($articleData === false) {
            throw new Exception("Pas d\'article");
        }

        return new Article(
            $articleData['title'],
            $articleData['content'],
            $articleData['created_at'],
            $articleData['id']
        );
    }

    public function findLast(): Article
    {
        $query = $this->pdo->query('SELECT * FROM article WHERE id = (SELECT MAX(id) FROM article)');
        $articleData = $query->fetch(PDO::FETCH_ASSOC);

        if ($articleData === false) {
            throw new Exception('Aucun article trouvé');
        }

        return new Article(
            $articleData['title'],
            $articleData['content'],
            $articleData['created_at'],
            $articleData['id']
        );
    }

    public function create(Article $article): void
    {
        $sql = 'INSERT INTO article (title, content, created_at)
      VALUES (:title, :content, :created_at)';

        try {
            $stmt = $this->pdo->prepare($sql);
            $stmt->bindValue(':title', $article->getTitle(), PDO::PARAM_STR);
            $stmt->bindValue(':content', $article->getContent(), PDO::PARAM_STR);
            $stmt->bindValue(':created_at', $article->getCreated_at(), PDO::PARAM_STR);

            $stmt->execute();
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
    }

    public function update($id, Article $article)
    {
        $sql = 'UPDATE article SET title = :title, content = :content, created_at = :created_at WHERE id = :id';
        try{
            $stmt = $this->pdo->prepare($sql);
            $stmt->bindValue(':title', $article->getTitle(), PDO::PARAM_STR);
            $stmt->bindValue(':content', $article->getContent(), PDO::PARAM_STR);
            $stmt->bindValue(':created_at', $article->getCreated_at(), PDO::PARAM_STR);
            $stmt->bindValue(':id', $id, PDO::PARAM_INT);
            $stmt->execute();
            var_dump($stmt->errorInfo());
        } catch (PDOException $e) {
            echo $e->getMessage();
        }
    }

    public function delete($id): void
    {
        $query = $this->pdo->prepare('DELETE FROM article WHERE id = :id');
        $query->bindValue(':id', $id);
        $query->execute();
    }
}